@@ -179,8 +179,9 @@ class DataRouter(tornado.web.Application):
                     await tornado.gen.sleep(0.25)
                 else:
                     break
-        except:
+        except Exception as err:
             # --- if this fails assume memcache is not available, move on
+            self.logger.info("cennot get data from memcache", exc_info=1)
             response = None
 
         if response is None:
@@ -192,7 +193,8 @@ class DataRouter(tornado.web.Application):
             try:
                 await self.cache.set(
                     req_uid, "CacheLocked", 10*TCP_TIMEOUT, noreply=True)
-            except:
+            except Exception as err:
+                self.logger.info("cannot lock memcache", exc_info=1)
                 pass
 
             while True:
@@ -229,7 +231,8 @@ class DataRouter(tornado.web.Application):
 
             try:
                 await self.cache.set(req_uid, response, expiry, noreply=True)
-            except:
+            except Exception as err:
+                self.logger.info("cannot access memcache", exc_info=1)
                 pass
 
             self.logger.debug(
@@ -256,7 +259,8 @@ class DataRouter(tornado.web.Application):
         req_uid = request_to_uid(req, real_time)
         try:
             await self.cache.delete(req_uid, noreply=True)
-        except:
+        except Exception as err:
+            self.logger.info("cannot access memcache", exc_info=1)
             pass
 
 
@@ -314,6 +318,7 @@ class BbgBDPHandler(BaseHandler):
             "sec": self.get_argument("sec"),
             "field": self.get_argument("field"),
             "overrides": self.get_argument("overrides", "null"),
+            "compress": self.get_argument("compress", False),
         }
 
         status, resp = await self.application.process_request(request, rt)
@@ -331,6 +336,7 @@ class BbgBDPHandler(BaseHandler):
             "sec": self.get_argument("sec"),
             "field": self.get_argument("field"),
             "overrides": self.get_argument("overrides", "null"),
+            "compress": self.get_argument("compress", False),
         }
 
         await self.application.clear_cache(request, rt)
@@ -350,6 +356,7 @@ class BbgBDHHandler(BaseHandler):
             "end": self.get_argument("end"),
             "adjusted": self.get_argument("adjusted", True),
             "overrides": self.get_argument("overrides", "null"),
+            "compress": self.get_argument("compress", False),
         }
 
         status, resp = await self.application.process_request(request, rt)
@@ -368,6 +375,7 @@ class BbgBDHHandler(BaseHandler):
             "end": self.get_argument("end"),
             "adjusted": self.get_argument("adjusted", True),
             "overrides": self.get_argument("overrides", "null"),
+            "compress": self.get_argument("compress", False),
         }
 
         await self.application.clear_cache(request, rt)
@@ -387,6 +395,7 @@ class BbgUniqueIdHandler(BaseHandler):
                 "sec": self.get_argument("sec"),
                 "field": self.get_argument("field"),
                 "overrides": self.get_argument("overrides", None),
+                "compress": self.get_argument("compress", False),
             }
         elif reqtype == "BDH":
             request = {
@@ -397,6 +406,7 @@ class BbgUniqueIdHandler(BaseHandler):
                 "end": self.get_argument("end"),
                 "adjusted": self.get_argument("adjusted", True),
                 "overrides": self.get_argument("overrides", None),
+                "compress": self.get_argument("compress", False),
             }
 
         req_uid = request_to_uid(request, rt)
