@@ -20,10 +20,12 @@ from onyx.core.database.ufo_base import custom_encoder, custom_decoder
 
 import json
 import hashlib
+import base64
+import zlib
 
 REQ_FIELDS = (
     "sec", "field", "start", "end",
-    "adjusted", "overrides", "type", "real-time", "compress")
+    "adjusted", "overrides", "type", "compress")
 
 
 # -----------------------------------------------------------------------------
@@ -37,6 +39,22 @@ def decode_message(msg):
     return json.loads(msg.decode("utf-8"), cls=custom_decoder)
 
 
+# -----------------------------------------------------------------------------
+def compress_payload(payload):
+    # --- serialize to json string
+    payload = json.dumps(payload, separators=(",", ":"), cls=custom_encoder)
+    # --- convert to bytes and compress
+    payload = zlib.compress(bytes(payload + "\n", "utf-8"))
+    # --- use base64 to get back a ascii string
+    return base64.b64encode(payload).decode("ascii")
+
+
+# -----------------------------------------------------------------------------
+def decompress_payload(payload):
+    return json.loads(
+        zlib.decompress(base64.b64decode(payload)), cls=custom_decoder)
+
+
 # -----------------------------------------------------------------------------
 def request_to_uid(request, real_time):
     # --- serialize request making sure we always get the same key for the
